# Copyright 2023 Weavers @ Eternal Loom. All rights reserved.
#
# Use of this software is governed by the license that can be
# found in LICENSE file in the source repository.

"""Smart Types (Smartypes) is a AI Integrated type system for modern applications.
"""
import logging

logger = logging.getLogger(__name__)


def main() -> None:
    """Entry point for the framework"""
    print("Not my type, or is it your's?")



# Copyright 2024 Weavers @ Eternal Loom. All rights reserved.
#
# Use of this software is governed by the license that can be
# found in LICENSE file in the source repository.

# Basic logging setup
import logging

from rich.logging import RichHandler

logger = logging.getLogger()

# Setup setup formatter for logging
shell_handler = RichHandler(show_time=False, show_path=False)
shell_format = '%(message)s'
shell_formatter = logging.Formatter(shell_format)
shell_handler.setFormatter(shell_formatter)
logger.addHandler(shell_handler)



"""
Copyright 2024 Weavers @ Eternal Loom. All rights reserved.
Use of this software is governed by the license that can be
found in LICENSE file in the source repository.
"""

# Copyright 2023 Weavers @ Eternal Loom. All rights reserved.
#
# Use of this software is governed by the license that can be
# found in LICENSE file in the source repository.


def test_module_import():
    """Test module import"""
    import copilib

    assert copilib is not None


def test_other_module_imports():
    """Test other module import"""
    import smartypes

    assert smartypes is not None
